@@ -5,7 +5,7 @@ use std::fs;
 
 #[tokio::main]
 async fn main() -> Result<()> {
-    let input = fs::read_to_string("fixtures/elvis.html").unwrap();
+    let input = fs::read_to_string("fixtures/bench/elvis.html").unwrap();
     let extractor = Extractor::default();
     let links = extractor.extract(&InputContent::from_string(&input, FileType::Html));
     println!("{links:#?}");
