@@ -1,20 +1,24 @@
+use crate::files_from::FilesFrom;
+use crate::generate::GenerateMode;
 use crate::parse::parse_base;
 use crate::verbosity::Verbosity;
 use anyhow::{Context, Error, Result, anyhow};
 use clap::builder::PossibleValuesParser;
-use clap::{Parser, arg, builder::TypedValueParser};
+use clap::{Parser, builder::TypedValueParser};
 use const_format::{concatcp, formatcp};
 use http::{
     HeaderMap,
     header::{HeaderName, HeaderValue},
 };
+use lychee_lib::Preprocessor;
+use lychee_lib::ratelimit::HostConfigs;
 use lychee_lib::{
     Base, BasicAuthSelector, DEFAULT_MAX_REDIRECTS, DEFAULT_MAX_RETRIES,
     DEFAULT_RETRY_WAIT_TIME_SECS, DEFAULT_TIMEOUT_SECS, DEFAULT_USER_AGENT, FileExtensions,
-    FileType, Input, StatusCodeExcluder, StatusCodeSelector, archive::Archive,
+    FileType, Input, StatusCodeSelector, archive::Archive,
 };
 use reqwest::tls;
-use secrecy::{ExposeSecret, SecretString};
+use secrecy::SecretString;
 use serde::{Deserialize, Deserializer};
 use std::collections::{HashMap, HashSet};
 use std::path::Path;
@@ -51,7 +55,9 @@ const HELP_MSG_CONFIG_FILE: &str = formatcp!(
 const TIMEOUT_STR: &str = concatcp!(DEFAULT_TIMEOUT_SECS);
 const RETRY_WAIT_TIME_STR: &str = concatcp!(DEFAULT_RETRY_WAIT_TIME_SECS);
 
-#[derive(Debug, Deserialize, Default, Clone, Display, EnumIter, EnumString, VariantNames)]
+#[derive(
+    Debug, Deserialize, Default, Clone, Display, EnumIter, EnumString, VariantNames, PartialEq, Eq,
+)]
 #[non_exhaustive]
 pub(crate) enum TlsVersion {
     #[serde(rename = "TLSv1_0")]
@@ -103,7 +109,7 @@ impl FromStr for StatsFormat {
             "json" => Ok(StatsFormat::Json),
             "markdown" | "md" => Ok(StatsFormat::Markdown),
             "raw" => Ok(StatsFormat::Raw),
-            _ => Err(anyhow!("Unknown format {}", format)),
+            _ => Err(anyhow!("Unknown format {format}")),
         }
     }
 }
@@ -190,13 +196,18 @@ default_function! {
     retry_wait_time: usize = DEFAULT_RETRY_WAIT_TIME_SECS;
     method: String = DEFAULT_METHOD.to_string();
     verbosity: Verbosity = Verbosity::default();
-    cache_exclude_selector: StatusCodeExcluder = StatusCodeExcluder::new();
-    accept_selector: StatusCodeSelector = StatusCodeSelector::default();
 }
 
 // Macro for merging configuration values
 macro_rules! fold_in {
-    ( $cli:ident , $toml:ident ; $( $key:ident : $default:expr; )* ) => {
+    ($cli:ident , $toml:ident ; $ty:ident { $(..$ignore:ident,)* $( $key:ident : $default:expr, )* } ) => {
+        if (false) {
+            #[allow(dead_code, unused, clippy::diverging_sub_expression)]
+            let _check_fold_in_exhaustivity = $ty {
+                $($key: unreachable!(), )*
+                $($ignore: unreachable!(), )*
+            };
+        };
         $(
             if $cli.$key == $default && $toml.$key != $default {
                 $cli.$key = $toml.$key;
@@ -221,11 +232,11 @@ fn parse_single_header(header: &str) -> Result<(HeaderName, HeaderValue)> {
     let parts: Vec<&str> = header.splitn(2, ':').collect();
     match parts.as_slice() {
         [name, value] => {
-            let name = HeaderName::from_str(name.trim())
-                .map_err(|e| anyhow!("Unable to convert header name '{}': {}", name.trim(), e))?;
-            let value = HeaderValue::from_str(value.trim()).map_err(|e| {
-                anyhow!("Unable to read value of header with name '{}': {}", name, e)
-            })?;
+            let name = name.trim();
+            let name = HeaderName::from_str(name)
+                .map_err(|e| anyhow!("Unable to convert header name '{name}': {e}"))?;
+            let value = HeaderValue::from_str(value.trim())
+                .map_err(|e| anyhow!("Unable to read value of header with name '{name}': {e}"))?;
             Ok((name, value))
         }
         _ => Err(anyhow!(
@@ -293,27 +304,35 @@ impl HeaderMapExt for HeaderMap {
         let mut header_map = HeaderMap::new();
         for (name, value) in headers {
             let header_name = HeaderName::from_bytes(name.as_bytes())
-                .map_err(|e| anyhow!("Invalid header name '{}': {}", name, e))?;
+                .map_err(|e| anyhow!("Invalid header name '{name}': {e}"))?;
             let header_value = HeaderValue::from_str(value)
-                .map_err(|e| anyhow!("Invalid header value '{}': {}", value, e))?;
+                .map_err(|e| anyhow!("Invalid header value '{value}': {e}"))?;
             header_map.insert(header_name, header_value);
         }
         Ok(header_map)
     }
 }
 
-/// A fast, async link checker
+/// lychee is a fast, asynchronous link checker which detects broken URLs and mail addresses
+/// in local files and websites. It supports Markdown and HTML and works well
+/// with many plain text file formats.
 ///
-/// Finds broken URLs and mail addresses inside Markdown, HTML,
-/// `reStructuredText`, websites and more!
+/// lychee is powered by lychee-lib, the Rust library for link checking.
 #[derive(Parser, Debug)]
-#[command(version, about)]
+#[command(version, about, next_display_order = None)]
 pub(crate) struct LycheeOptions {
-    /// The inputs (where to get links to check from).
-    /// These can be: files (e.g. `README.md`), file globs (e.g. `"~/git/*/README.md"`),
-    /// remote URLs (e.g. `https://example.com/README.md`) or standard input (`-`).
-    /// NOTE: Use `--` to separate inputs from options that allow multiple arguments.
-    #[arg(name = "inputs", required = true)]
+    /// Inputs for link checking (where to get links to check from).
+    #[arg(
+        name = "inputs",
+        required_unless_present = "files_from",
+        required_unless_present = "generate",
+        long_help = "Inputs for link checking (where to get links to check from). These can be:
+files (e.g. `README.md`), file globs (e.g. `'~/git/*/README.md'`), remote URLs
+(e.g. `https://example.com/README.md`), or standard input (`-`). Alternatively,
+use `--files-from` to read inputs from a file.
+
+NOTE: Use `--` to separate inputs from options that allow multiple arguments."
+    )]
     raw_inputs: Vec<String>,
 
     /// Configuration file to use
@@ -331,9 +350,25 @@ impl LycheeOptions {
     // accept a `Vec<Input>` in `LycheeOptions` and do the conversion there, but
     // we wouldn't get access to `glob_ignore_case`.
     pub(crate) fn inputs(&self) -> Result<HashSet<Input>> {
-        self.raw_inputs
+        let mut all_inputs = self.raw_inputs.clone();
+
+        // If --files-from is specified, read inputs from the file
+        if let Some(files_from_path) = &self.config.files_from {
+            let files_from = FilesFrom::try_from(files_from_path.as_path())
+                .context("Cannot read inputs from --files-from")?;
+            all_inputs.extend(files_from.inputs);
+        }
+
+        // Convert default extension to FileType if provided
+        let default_file_type = self
+            .config
+            .default_extension
+            .as_deref()
+            .and_then(FileType::from_extension);
+
+        all_inputs
             .iter()
-            .map(|raw_input| Input::new(raw_input, None, self.config.glob_ignore_case))
+            .map(|raw_input| Input::new(raw_input, default_file_type, self.config.glob_ignore_case))
             .collect::<Result<_, _>>()
             .context("Cannot parse inputs from arguments")
     }
@@ -351,7 +386,30 @@ where
 /// The main configuration for lychee
 #[allow(clippy::struct_excessive_bools)]
 #[derive(Parser, Debug, Deserialize, Clone, Default)]
+#[serde(deny_unknown_fields)]
 pub(crate) struct Config {
+    /// Read input filenames from the given file or stdin (if path is '-').
+    #[arg(
+        long,
+        value_name = "PATH",
+        long_help = "Read input filenames from the given file or stdin (if path is '-').
+
+This is useful when you have a large number of inputs that would be
+cumbersome to specify on the command line directly.
+
+Examples:
+
+    lychee --files-from list.txt
+    find . -name '*.md' | lychee --files-from -
+    echo 'README.md' | lychee --files-from -
+
+File Format:
+- Each line should contain one input (file path, URL, or glob pattern).
+- Lines starting with '#' are treated as comments and ignored.
+- Empty lines are also ignored."
+    )]
+    files_from: Option<PathBuf>,
+
     /// Verbose program output
     #[clap(flatten)]
     #[serde(default = "verbosity")]
@@ -363,6 +421,11 @@ pub(crate) struct Config {
     #[serde(default)]
     pub(crate) no_progress: bool,
 
+    /// Show per-host statistics at the end of the run
+    #[arg(long)]
+    #[serde(default)]
+    pub(crate) host_stats: bool,
+
     /// A list of file extensions. Files not matching the specified extensions are skipped.
     ///
     /// E.g. a user can specify `--extensions html,htm,php,asp,aspx,jsp,cgi`
@@ -382,6 +445,18 @@ specify both extensions explicitly."
     #[serde(default = "FileExtensions::default")]
     pub(crate) extensions: FileExtensions,
 
+    /// This is the default file extension that is applied to files without an extension.
+    ///
+    /// This is useful for files without extensions or with unknown extensions.
+    /// The extension will be used to determine the file type for processing.
+    ///
+    /// Examples:
+    ///   --default-extension md
+    ///   --default-extension html
+    #[arg(long, value_name = "EXTENSION", verbatim_doc_comment)]
+    #[serde(default)]
+    pub(crate) default_extension: Option<String>,
+
     #[arg(help = HELP_MSG_CACHE)]
     #[arg(long)]
     #[serde(default)]
@@ -400,7 +475,6 @@ specify both extensions explicitly."
     /// A list of status codes that will be excluded from the cache
     #[arg(
         long,
-        default_value_t,
         long_help = "A list of status codes that will be ignored from the cache
 
 The following exclude range syntax is supported: [start]..[[=]end]|code. Some valid
@@ -412,12 +486,11 @@ examples are:
 - 500..=599 (excludes any status code from 500 to 599 inclusive)
 - 500..600 (excludes any status code from 500 to 600 excluding 600, same as 500..=599)
 
-Use \"lychee --cache-exclude-status '429, 500..502' <inputs>...\" to provide a comma- separated
-list of excluded status codes. This example will not cache results with a status code of 429, 500
-and 501."
+Use \"lychee --cache-exclude-status '429, 500..502' <inputs>...\" to provide a
+comma-separated list of excluded status codes. This example will not cache results
+with a status code of 429, 500 and 501."
     )]
-    #[serde(default = "cache_exclude_selector")]
-    pub(crate) cache_exclude_status: StatusCodeExcluder,
+    pub(crate) cache_exclude_status: Option<StatusCodeSelector>,
 
     /// Don't perform any link checking.
     /// Instead, dump all the links extracted from inputs that would be checked
@@ -463,6 +536,34 @@ and 501."
     #[serde(default = "max_concurrency")]
     pub(crate) max_concurrency: usize,
 
+    /// Default maximum concurrent requests per host (default: 10)
+    ///
+    /// This limits the maximum amount of requests that are sent simultaneously
+    /// to the same host. This helps to prevent overwhelming servers and
+    /// running into rate-limits. Use the `hosts` option to configure this
+    /// on a per-host basis.
+    ///
+    /// Examples:
+    ///   --host-concurrency 2   # Conservative for slow APIs
+    ///   --host-concurrency 20  # Aggressive for fast APIs
+    #[arg(long, verbatim_doc_comment)]
+    #[serde(default)]
+    pub(crate) host_concurrency: Option<usize>,
+
+    /// Minimum interval between requests to the same host (default: 50ms)
+    ///
+    /// Sets a baseline delay between consecutive requests to prevent
+    /// overloading servers. The adaptive algorithm may increase this based
+    /// on server responses (rate limits, errors). Use the `hosts` option
+    /// to configure this on a per-host basis.
+    ///
+    /// Examples:
+    ///   --host-request-interval 50ms   # Fast for robust APIs
+    ///   --host-request-interval 1s     # Conservative for rate-limited APIs
+    #[arg(long, value_parser = humantime::parse_duration, verbatim_doc_comment)]
+    #[serde(default, with = "humantime_serde")]
+    pub(crate) host_request_interval: Option<Duration>,
+
     /// Number of threads to utilize.
     /// Defaults to number of cores available to the system
     #[arg(short = 'T', long)]
@@ -482,7 +583,12 @@ and 501."
     /// Only test links with the given schemes (e.g. https).
     /// Omit to check links with any other scheme.
     /// At the moment, we support http, https, file, and mailto.
-    #[arg(short, long)]
+    #[arg(
+        short,
+        long,
+        long_help = "Only test links with the given schemes (e.g. https). Omit to check links with
+any other scheme. At the moment, we support http, https, file, and mailto."
+    )]
     #[serde(default)]
     pub(crate) scheme: Vec<String>,
 
@@ -555,7 +661,9 @@ will be checked in order of appearance.
 
 Example: --fallback-extensions html,htm,php,asp,aspx,jsp,cgi
 
-Note: This option only takes effect on `file://` URIs which do not exist."
+Note: This option takes effect on `file://` URIs which do not exist and on
+      `file://` URIs pointing to directories which resolve to themself (by the
+      --index-files logic)."
     )]
     pub(crate) fallback_extensions: Vec<String>,
 
@@ -592,7 +700,7 @@ Note: This option only takes effect on `file://` URIs which exist and point to a
     /// Set custom header for requests
     #[arg(
         short = 'H',
-        long = "header",
+        long,
         // Note: We use a `Vec<(String, String)>` for headers, which is
         // unfortunate. The reason is that `clap::ArgAction::Append` collects
         // multiple values, and `clap` cannot automatically convert these tuples
@@ -605,7 +713,9 @@ Note: This option only takes effect on `file://` URIs which exist and point to a
 Some websites require custom headers to be passed in order to return valid responses.
 You can specify custom headers in the format 'Name: Value'. For example, 'Accept: text/html'.
 This is the same format that other tools like curl or wget use.
-Multiple headers can be specified by using the flag multiple times."
+Multiple headers can be specified by using the flag multiple times.
+The specified headers are used for ALL requests.
+Use the `hosts` option to configure headers on a per-host basis."
     )]
     #[serde(default)]
     #[serde(deserialize_with = "deserialize_headers")]
@@ -615,7 +725,6 @@ Multiple headers can be specified by using the flag multiple times."
     #[arg(
         short,
         long,
-        default_value_t,
         long_help = "A List of accepted status codes for valid links
 
 The following accept range syntax is supported: [start]..[[=]end]|code. Some valid
@@ -629,10 +738,10 @@ examples are:
 
 Use \"lychee --accept '200..=204, 429, 500' <inputs>...\" to provide a comma-
 separated list of accepted status codes. This example will accept 200, 201,
-202, 203, 204, 429, and 500 as valid status codes."
+202, 203, 204, 429, and 500 as valid status codes.
+Defaults to '100..=103,200..=299' if the user provides no value."
     )]
-    #[serde(default = "accept_selector")]
-    pub(crate) accept: StatusCodeSelector,
+    pub(crate) accept: Option<StatusCodeSelector>,
 
     /// Enable the checking of fragments in links.
     #[arg(long)]
@@ -660,15 +769,52 @@ separated list of accepted status codes. This example will accept 200, 201,
     #[serde(skip)]
     pub(crate) base: Option<Base>,
 
-    /// Base URL used to resolve relative URLs during link checking
+    /// Base URL used to resolve relative URLs in local files.
     /// Example: <https://example.com>
-    #[arg(short, long, value_parser= parse_base)]
+    #[arg(
+        short,
+        long,
+        value_parser = parse_base,
+        long_help = "Base URL to use when resolving relative URLs in local files. If specified,
+relative links in local files are interpreted as being relative to the given
+base URL.
+
+For example, given a base URL of `https://example.com/dir/page`, the link `a`
+would resolve to `https://example.com/dir/a` and the link `/b` would resolve
+to `https://example.com/b`. This behavior is not affected by the filesystem
+path of the file containing these links.
+
+Note that relative URLs without a leading slash become siblings of the base
+URL. If, instead, the base URL ended in a slash, the link would become a child
+of the base URL. For example, a base URL of `https://example.com/dir/page/` and
+a link of `a` would resolve to `https://example.com/dir/page/a`.
+
+Basically, the base URL option resolves links as if the local files were hosted
+at the given base URL address.
+
+The provided base URL value must either be a URL (with scheme) or an absolute path.
+Note that certain URL schemes cannot be used as a base, e.g., `data` and `mailto`."
+    )]
     #[serde(default)]
     pub(crate) base_url: Option<Base>,
 
-    /// Root path to use when checking absolute local links,
-    /// must be an absolute path
-    #[arg(long)]
+    /// Root directory to use when checking absolute links in local files.
+    /// Must be an absolute path.
+    #[arg(
+        long,
+        long_help = "Root directory to use when checking absolute links in local files. This option is
+required if absolute links appear in local files, otherwise those links will be
+flagged as errors. This must be an absolute path (i.e., one beginning with `/`).
+
+If specified, absolute links in local files are resolved by prefixing the given
+root directory to the requested absolute link. For example, with a root-dir of
+`/root/dir`, a link to `/page.html` would be resolved to `/root/dir/page.html`.
+
+This option can be specified alongside `--base-url`. If both are given, an
+absolute link is resolved by constructing a URL from three parts: the domain
+name specified in `--base-url`, followed by the `--root-dir` directory path,
+followed by the absolute link's own path."
+    )]
     #[serde(default)]
     pub(crate) root_dir: Option<PathBuf>,
 
@@ -723,23 +869,67 @@ separated list of accepted status codes. This example will accept 200, 201,
     #[serde(default)]
     pub(crate) format: StatsFormat,
 
+    /// Generate special output (e.g. the man page) instead of performing link checking
+    #[arg(long, value_parser = PossibleValuesParser::new(GenerateMode::VARIANTS).map(|s| s.parse::<GenerateMode>().unwrap()))]
+    pub(crate) generate: Option<GenerateMode>,
+
     /// When HTTPS is available, treat HTTP links as errors
     #[arg(long)]
     #[serde(default)]
     pub(crate) require_https: bool,
 
-    /// Tell lychee to read cookies from the given file.
-    /// Cookies will be stored in the cookie jar and sent with requests.
-    /// New cookies will be stored in the cookie jar and existing cookies will be updated.
-    #[arg(long)]
+    /// Read and write cookies using the given file
+    #[arg(
+        long,
+        long_help = "Tell lychee to read cookies from the given file. Cookies will be stored in the
+cookie jar and sent with requests. New cookies will be stored in the cookie jar
+and existing cookies will be updated."
+    )]
     #[serde(default)]
     pub(crate) cookie_jar: Option<PathBuf>,
 
     #[allow(clippy::doc_markdown)]
-    /// Check WikiLinks in Markdown files
+    /// Check WikiLinks in Markdown files, this requires specifying --base-url
+    #[clap(requires = "base_url")]
     #[arg(long)]
     #[serde(default)]
     pub(crate) include_wikilinks: bool,
+
+    /// Preprocess input files.
+    #[arg(
+        short,
+        long,
+        value_name = "COMMAND",
+        long_help = r#"Preprocess input files.
+For each file input, this flag causes lychee to execute `COMMAND PATH` and process
+its standard output instead of the original contents of PATH. This allows you to
+convert files that would otherwise not be understood by lychee. The preprocessor
+COMMAND is only run on input files, not on standard input or URLs.
+
+To invoke programs with custom arguments or to use multiple preprocessors, use a
+wrapper program such as a shell script. An example script looks like this:
+
+#!/usr/bin/env bash
+case "$1" in
+*.pdf)
+    exec pdftohtml -i -s -stdout "$1"
+    ;;
+*.odt|*.docx|*.epub|*.ipynb)
+    exec pandoc "$1" --to=html --wrap=none
+    ;;
+*)
+    # identity function, output input without changes
+    exec cat
+    ;;
+esac"#
+    )]
+    #[serde(default)]
+    pub(crate) preprocess: Option<Preprocessor>,
+
+    /// Host-specific configurations from config file
+    #[arg(skip)]
+    #[serde(default)]
+    pub(crate) hosts: HostConfigs,
 }
 
 impl Config {
@@ -769,67 +959,90 @@ impl Config {
         // Special handling for headers before fold_in!
         self.merge_headers(&toml.header);
 
+        // If the config file has a value for the GitHub token, but the CLI
+        // doesn't, use the token from the config file.
+        // This is outside of fold_in! because SecretBox doesn't implement Eq.
+        if self.github_token.is_none() && toml.github_token.is_some() {
+            self.github_token = toml.github_token;
+        }
+
+        // Hosts configuration is only available in TOML for now (not in the CLI)
+        // That's because it's a bit complex to specify on the command line and
+        // we didn't come up with a good syntax for it yet.
+        self.hosts = toml.hosts;
+
+        // NOTE: if you see an error within this macro call, check to make sure that
+        // that the fields provided to fold_in! match all the fields of the Config struct.
         fold_in! {
             // Destination and source configs
             self, toml;
 
-            // Keys with defaults to assign
-            accept: StatusCodeSelector::default();
-            base_url: None;
-            basic_auth: None;
-            cache_exclude_status: StatusCodeExcluder::default();
-            cache: false;
-            cookie_jar: None;
-            exclude_all_private: false;
-            exclude_file: Vec::<String>::new(); // deprecated
-            exclude_link_local: false;
-            exclude_loopback: false;
-            exclude_path: Vec::<String>::new();
-            exclude_private: false;
-            exclude: Vec::<String>::new();
-            extensions: FileType::default_extensions();
-            fallback_extensions: Vec::<String>::new();
-            format: StatsFormat::default();
-            glob_ignore_case: false;
-            header: Vec::<(String, String)>::new();
-            include_fragments: false;
-            include_mail: false;
-            include_verbatim: false;
-            include_wikilinks: false;
-            include: Vec::<String>::new();
-            insecure: false;
-            max_cache_age: humantime::parse_duration(DEFAULT_MAX_CACHE_AGE).unwrap();
-            max_concurrency: DEFAULT_MAX_CONCURRENCY;
-            max_redirects: DEFAULT_MAX_REDIRECTS;
-            max_retries: DEFAULT_MAX_RETRIES;
-            method: DEFAULT_METHOD;
-            no_progress: false;
-            output: None;
-            remap: Vec::<String>::new();
-            require_https: false;
-            retry_wait_time: DEFAULT_RETRY_WAIT_TIME_SECS;
-            scheme: Vec::<String>::new();
-            skip_missing: false;
-            threads: None;
-            timeout: DEFAULT_TIMEOUT_SECS;
-            user_agent: DEFAULT_USER_AGENT;
-            verbose: Verbosity::default();
-        }
+            Config {
+                // Keys which are handled outside of fold_in
+                ..header,
+                ..github_token,
+                ..hosts,
 
-        // If the config file has a value for the GitHub token, but the CLI
-        // doesn't, use the token from the config file.
-        if self
-            .github_token
-            .as_ref()
-            .map(ExposeSecret::expose_secret)
-            .is_none()
-            && toml
-                .github_token
-                .as_ref()
-                .map(ExposeSecret::expose_secret)
-                .is_some()
-        {
-            self.github_token = toml.github_token;
+                // Keys with defaults to assign
+                accept: None,
+                archive: None,
+                base: None,
+                base_url: None,
+                basic_auth: None,
+                cache: false,
+                cache_exclude_status: None,
+                cookie_jar: None,
+                default_extension: None,
+                host_concurrency: None,
+                host_request_interval: None,
+                dump: false,
+                dump_inputs: false,
+                exclude: Vec::<String>::new(),
+                exclude_all_private: false,
+                exclude_file: Vec::<String>::new(), // deprecated
+                exclude_link_local: false,
+                exclude_loopback: false,
+                exclude_path: Vec::<String>::new(),
+                exclude_private: false,
+                extensions: FileType::default_extensions(),
+                fallback_extensions: Vec::<String>::new(),
+                files_from: None,
+                format: StatsFormat::default(),
+                generate: None,
+                glob_ignore_case: false,
+                hidden: false,
+                host_stats: false,
+                include: Vec::<String>::new(),
+                include_fragments: false,
+                include_mail: false,
+                include_verbatim: false,
+                include_wikilinks: false,
+                index_files: None,
+                insecure: false,
+                max_cache_age: humantime::parse_duration(DEFAULT_MAX_CACHE_AGE).unwrap(),
+                max_concurrency: DEFAULT_MAX_CONCURRENCY,
+                max_redirects: DEFAULT_MAX_REDIRECTS,
+                max_retries: DEFAULT_MAX_RETRIES,
+                method: DEFAULT_METHOD,
+                min_tls: None,
+                mode: OutputMode::Color,
+                no_ignore: false,
+                no_progress: false,
+                offline: false,
+                output: None,
+                preprocess: None,
+                remap: Vec::<String>::new(),
+                require_https: false,
+                retry_wait_time: DEFAULT_RETRY_WAIT_TIME_SECS,
+                root_dir: None,
+                scheme: Vec::<String>::new(),
+                skip_missing: false,
+                suggest: false,
+                threads: None,
+                timeout: DEFAULT_TIMEOUT_SECS,
+                user_agent: DEFAULT_USER_AGENT,
+                verbose: Verbosity::default(),
+            }
         }
     }
 }
@@ -840,34 +1053,6 @@ mod tests {
 
     use super::*;
 
-    #[test]
-    fn test_accept_status_codes() {
-        let toml = Config {
-            accept: StatusCodeSelector::from_str("200..=204, 429, 500").unwrap(),
-            ..Default::default()
-        };
-
-        let mut cli = Config::default();
-        cli.merge(toml);
-
-        assert!(cli.accept.contains(429));
-        assert!(cli.accept.contains(200));
-        assert!(cli.accept.contains(203));
-        assert!(cli.accept.contains(204));
-        assert!(!cli.accept.contains(205));
-    }
-
-    #[test]
-    fn test_default() {
-        let cli = Config::default();
-
-        assert_eq!(
-            cli.accept,
-            StatusCodeSelector::from_str("100..=103,200..=299").expect("no error")
-        );
-        assert_eq!(cli.cache_exclude_status, StatusCodeExcluder::new());
-    }
-
     #[test]
     fn test_parse_custom_headers() {
         assert_eq!(
