@@ -8,13 +8,14 @@ mod cookies;
 mod error;
 mod file;
 mod input;
-pub(crate) mod mail;
+mod preprocessor;
 pub(crate) mod redirect_history;
 mod request;
+mod request_error;
 pub(crate) mod resolver;
 mod response;
 mod status;
-mod status_code;
+mod status_code_selector;
 pub(crate) mod uri;
 
 pub use accept::*;
@@ -25,11 +26,16 @@ pub use cookies::CookieJar;
 pub use error::ErrorKind;
 pub use file::{FileExtensions, FileType};
 pub use input::{Input, InputContent, InputResolver, InputSource, ResolvedInputSource};
-pub use redirect_history::Redirects;
+pub use preprocessor::Preprocessor;
+pub use redirect_history::{Redirect, Redirects};
 pub use request::Request;
+pub use request_error::RequestError;
 pub use response::{Response, ResponseBody};
 pub use status::Status;
-pub use status_code::*;
+pub use status_code_selector::*;
 
 /// The lychee `Result` type
 pub type Result<T> = std::result::Result<T, crate::ErrorKind>;
+
+/// The lychee `Result` type, aliased to avoid conflicting with [`std::result::Result`].
+pub type LycheeResult<T> = Result<T>;
