@@ -1,6 +1,9 @@
-#!/bin/bash
+#!/usr/bin/env bash
 set -e
 
+export CARGO_HOME="${CARGO_HOME:-$HOME/.cargo}"
+export PATH="$CARGO_HOME/bin:$PATH"
+
 # Auto-install lychee if not found
 if ! command -v lychee &> /dev/null; then
     echo "Installing lychee..."
@@ -16,5 +19,10 @@ if ! command -v lychee &> /dev/null; then
     fi
 fi
 
+command -v lychee >/dev/null || {
+    echo "lychee installation failed or binary not found in PATH" >&2
+    exit 1
+}
+
 # Run lychee with all passed arguments
 exec lychee "$@"
\ No newline at end of file
